"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const React = require("react");
const react_syntax_highlighter_1 = require("react-syntax-highlighter");
const hljs_1 = require("react-syntax-highlighter/styles/hljs");
delete hljs_1.tomorrowNight.hljs['background'];
delete hljs_1.arduinoLight.hljs['background'];
const utils_1 = require("./utils");
const BYTECODE_PANEL_CLASS = 'jp-RenderedPythonBytecode';
const BYTECODE_ERROR_CLASS = 'jp-RenderedPythonBytecodeError';
const BYTECODE_HIGHLIGHT = 'jp-HighlightBytecode';
class BytecodeView extends apputils_1.VDomRenderer {
    constructor(model) {
        super();
        this.id = 'PythonBytecode';
        this.model = model;
        this.addClass(BYTECODE_PANEL_CLASS);
    }
    render() {
        if (this.model.error) {
            return React.createElement("div", { className: BYTECODE_ERROR_CLASS }, this.model.error);
        }
        const theme = this.model.isLight ? hljs_1.arduinoLight : hljs_1.tomorrowNight;
        const elements = utils_1.parseBytecode(this.model.output);
        const selectedLines = this.model.selectedLines;
        let out = elements.map(block => {
            const { line, code } = block;
            return (React.createElement("div", { className: selectedLines && selectedLines.has(line) ? BYTECODE_HIGHLIGHT : '' },
                React.createElement(react_syntax_highlighter_1.default, { language: "python", style: theme }, code)));
        });
        return React.createElement("div", null, out);
    }
}
exports.BytecodeView = BytecodeView;
